/*
 *
 *  Created on: Mar 1, 2021
 *      Author: astrisw
 */

#pragma once

#include <Base_Provider.h>
#include <unordered_map>
#include <hiredis/hiredis.h>
#include <Base_Configurator.h>

namespace inaf::oasbo::Providers {

class RedisProvider: public BaseProvider {
protected:
	redisContext *context = nullptr;

	RedisProvider();
	RedisProvider(std::string ip, int port, std::string key);

public:
	std::string ip;
	int port;

	int write(PacketLib::BasePacket&) override;
	int write(PacketLib::BasePacket&, std::string dest) override;
	void setDest(std::string dest) override {
		this->dest = dest;
	}
	std::string getDest() override {
		return dest;
	}
	int close() override;
	int open() override;
	bool isOpen() override;
	~RedisProvider();

	friend class Builder;

	class Builder {
	protected:
		RedisProvider *provider;

	public:

		std::string ip_key { "ip" };
		std::string port_key { "port" };
		std::string redis_key_key { "key" };

		Builder();
		Builder(std::string ip, int port, std::string topic);
		~Builder();

		void reset();

		Builder* configFrom(Configurators::BaseConfigurator *conf);

		Builder* setIp(std::string ip);

		Builder* setPort(int port);

		Builder* setKey(std::string key);

		RedisProvider* getProvider();
	};

};
}
