#include <tclap/CmdLine.h>
#include <Redis_Provider_Configurator.h>

namespace inaf::oasbo::Providers {

RedisProviderConfigurator::RedisProviderConfigurator(){
	setRedisIP("127.0.0.1");
	setRedisPort(6379);
	setRedisKey("DAQ_Key");
}


RedisProviderConfigurator::RedisProviderConfigurator(int argc, char ** argv){
	try {
		TCLAP::CmdLine cmd("Usage Description WIP", ' ', "1");
		cmd.ignoreUnmatched(true);
		TCLAP::ValueArg<std::string> redisIP("","redisIp","redis IP address",false,"127.0.0.1","X.X.X.X");
		cmd.add( redisIP );
		TCLAP::ValueArg<std::string> redisPort("","redisPort","redis listening port",false,"6379","int");
		cmd.add( redisPort );
		TCLAP::ValueArg<std::string> defaultKey("","redisKey","redis destination key",false,"DAQ_key","string");
		cmd.add( defaultKey );

		cmd.parse( argc, argv );

		setRedisIP(redisIP.getValue());
		setRedisPort(std::stoi(redisPort.getValue()));
		setRedisKey(defaultKey.getValue());
	}catch (TCLAP::ArgException &e){  // catch any exceptions
		std::cerr << "error: " << e.error() << " for arg " << e.argId() << std::endl;
		exit(EXIT_FAILURE);
	}
}

BaseProvider * RedisProviderConfigurator::createProvider(){
	return new RedisProvider(getRedisIP(),getRedisPort(), getRedisKey());
}

RedisProvider * RedisProviderConfigurator::createRedisProvider(){
	return new RedisProvider(getRedisIP(),getRedisPort(), getRedisKey());
}

void RedisProviderConfigurator::createRedisProvider(RedisProvider & prov){
	prov.setIp(getRedisIP());
	prov.setPort(getRedisPort());
	prov.setKey(getRedisKey());
}
}
